jint java_lang_reflect_Method_getModifiers(JNIEnv* env, jobject methodObject);
jobjectArray java_lang_reflect_Method_getParameterTypes(JNIEnv* env, jobject methodObject);
jclass java_lang_reflect_Method_getReturnType(JNIEnv* env, jobject methodObject);
jobject java_lang_reflect_Method_invokeNative(JNIEnv* env, jobject clazz, jobject obj, jobjectArray args,jclass theclass, jint slot);
jobjectArray java_lang_reflect_Method_getExceptionTypes(JNIEnv* env, jobject methodObject);
